# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/tirons/src/akvo/akvo/gui/main.ui'
#
# Created by: PyQt5 UI code generator 5.12.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1142, 875)
        MainWindow.setMinimumSize(QtCore.QSize(1142, 0))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.scrollArea = QtWidgets.QScrollArea(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollArea.sizePolicy().hasHeightForWidth())
        self.scrollArea.setSizePolicy(sizePolicy)
        self.scrollArea.setMinimumSize(QtCore.QSize(550, 0))
        self.scrollArea.setMaximumSize(QtCore.QSize(550, 16777215))
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 537, 882))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents.setMinimumSize(QtCore.QSize(0, 0))
        self.scrollAreaWidgetContents.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.ProcTabs = QtWidgets.QTabWidget(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ProcTabs.sizePolicy().hasHeightForWidth())
        self.ProcTabs.setSizePolicy(sizePolicy)
        self.ProcTabs.setMinimumSize(QtCore.QSize(525, 0))
        self.ProcTabs.setMaximumSize(QtCore.QSize(525, 16777215))
        self.ProcTabs.setMouseTracking(True)
        self.ProcTabs.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.ProcTabs.setElideMode(QtCore.Qt.ElideLeft)
        self.ProcTabs.setUsesScrollButtons(True)
        self.ProcTabs.setTabsClosable(False)
        self.ProcTabs.setTabBarAutoHide(True)
        self.ProcTabs.setObjectName("ProcTabs")
        self.LoadTab = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LoadTab.sizePolicy().hasHeightForWidth())
        self.LoadTab.setSizePolicy(sizePolicy)
        self.LoadTab.setMinimumSize(QtCore.QSize(940, 0))
        self.LoadTab.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.LoadTab.setObjectName("LoadTab")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.LoadTab)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.inputRAWParametersBox = QtWidgets.QGroupBox(self.LoadTab)
        self.inputRAWParametersBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.inputRAWParametersBox.sizePolicy().hasHeightForWidth())
        self.inputRAWParametersBox.setSizePolicy(sizePolicy)
        self.inputRAWParametersBox.setMinimumSize(QtCore.QSize(505, 125))
        self.inputRAWParametersBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.inputRAWParametersBox.setObjectName("inputRAWParametersBox")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.inputRAWParametersBox)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label = QtWidgets.QLabel(self.inputRAWParametersBox)
        self.label.setToolTip("")
        self.label.setStatusTip("")
        self.label.setObjectName("label")
        self.gridLayout_4.addWidget(self.label, 0, 0, 1, 1)
        self.stacksLineEdit = QtWidgets.QLineEdit(self.inputRAWParametersBox)
        self.stacksLineEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.stacksLineEdit.setToolTip("<html><head/><body><p>Set the stacks that you would like processed.</p><p>This must be a valid set of numpy array indices. Remember that Python uses non end-inclusive indexing. </p><p>So things like [1:24] will include stacks 1-23</p><p>Furthermore [1:8,12:24] will include stacks 1-7 and 12:23. Any list of valid indices will be accepted, but they must be comma seperated. </p></body></html>")
        self.stacksLineEdit.setObjectName("stacksLineEdit")
        self.gridLayout_4.addWidget(self.stacksLineEdit, 0, 1, 1, 1)
        self.label_24 = QtWidgets.QLabel(self.inputRAWParametersBox)
        self.label_24.setObjectName("label_24")
        self.gridLayout_4.addWidget(self.label_24, 0, 2, 1, 1)
        self.DeadTimeSpinBox = QtWidgets.QDoubleSpinBox(self.inputRAWParametersBox)
        self.DeadTimeSpinBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.DeadTimeSpinBox.setMinimum(0.5)
        self.DeadTimeSpinBox.setSingleStep(0.5)
        self.DeadTimeSpinBox.setProperty("value", 5.0)
        self.DeadTimeSpinBox.setObjectName("DeadTimeSpinBox")
        self.gridLayout_4.addWidget(self.DeadTimeSpinBox, 0, 3, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.inputRAWParametersBox)
        self.label_23.setObjectName("label_23")
        self.gridLayout_4.addWidget(self.label_23, 1, 0, 1, 1)
        self.dataChanLineEdit = QtWidgets.QLineEdit(self.inputRAWParametersBox)
        self.dataChanLineEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dataChanLineEdit.setObjectName("dataChanLineEdit")
        self.gridLayout_4.addWidget(self.dataChanLineEdit, 1, 1, 1, 1)
        self.label_28 = QtWidgets.QLabel(self.inputRAWParametersBox)
        self.label_28.setObjectName("label_28")
        self.gridLayout_4.addWidget(self.label_28, 1, 2, 1, 1)
        self.refChanLineEdit = QtWidgets.QLineEdit(self.inputRAWParametersBox)
        self.refChanLineEdit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.refChanLineEdit.setText("")
        self.refChanLineEdit.setObjectName("refChanLineEdit")
        self.gridLayout_4.addWidget(self.refChanLineEdit, 1, 3, 1, 1)
        self.label_29 = QtWidgets.QLabel(self.inputRAWParametersBox)
        self.label_29.setObjectName("label_29")
        self.gridLayout_4.addWidget(self.label_29, 2, 0, 1, 1)
        self.FIDProcComboBox = QtWidgets.QComboBox(self.inputRAWParametersBox)
        self.FIDProcComboBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.FIDProcComboBox.setObjectName("FIDProcComboBox")
        self.gridLayout_4.addWidget(self.FIDProcComboBox, 2, 1, 1, 1)
        self.plotImportCheckBox = QtWidgets.QCheckBox(self.inputRAWParametersBox)
        self.plotImportCheckBox.setEnabled(False)
        self.plotImportCheckBox.setChecked(True)
        self.plotImportCheckBox.setObjectName("plotImportCheckBox")
        self.gridLayout_4.addWidget(self.plotImportCheckBox, 2, 2, 1, 1)
        self.loadDataPushButton = QtWidgets.QPushButton(self.inputRAWParametersBox)
        self.loadDataPushButton.setEnabled(False)
        self.loadDataPushButton.setStyleSheet("#loadDataPushButton {\n"
"    background: green;\n"
"}\n"
"\n"
"#loadDataPushButton:disabled {\n"
"    background: black;\n"
"}")
        self.loadDataPushButton.setObjectName("loadDataPushButton")
        self.gridLayout_4.addWidget(self.loadDataPushButton, 2, 3, 1, 1)
        self.verticalLayout_3.addWidget(self.inputRAWParametersBox)
        self.downSampleGroupBox = QtWidgets.QGroupBox(self.LoadTab)
        self.downSampleGroupBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.downSampleGroupBox.sizePolicy().hasHeightForWidth())
        self.downSampleGroupBox.setSizePolicy(sizePolicy)
        self.downSampleGroupBox.setMinimumSize(QtCore.QSize(505, 90))
        self.downSampleGroupBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.downSampleGroupBox.setCheckable(True)
        self.downSampleGroupBox.setObjectName("downSampleGroupBox")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.downSampleGroupBox)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label_3 = QtWidgets.QLabel(self.downSampleGroupBox)
        self.label_3.setObjectName("label_3")
        self.gridLayout_5.addWidget(self.label_3, 0, 0, 1, 1)
        self.truncateSpinBox = QtWidgets.QSpinBox(self.downSampleGroupBox)
        self.truncateSpinBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.truncateSpinBox.setMaximum(1000)
        self.truncateSpinBox.setProperty("value", 0)
        self.truncateSpinBox.setObjectName("truncateSpinBox")
        self.gridLayout_5.addWidget(self.truncateSpinBox, 0, 1, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.downSampleGroupBox)
        self.label_12.setObjectName("label_12")
        self.gridLayout_5.addWidget(self.label_12, 1, 0, 1, 1)
        self.downSampleSpinBox = QtWidgets.QSpinBox(self.downSampleGroupBox)
        self.downSampleSpinBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.downSampleSpinBox.setMinimum(1)
        self.downSampleSpinBox.setMaximum(5)
        self.downSampleSpinBox.setProperty("value", 5)
        self.downSampleSpinBox.setObjectName("downSampleSpinBox")
        self.gridLayout_5.addWidget(self.downSampleSpinBox, 1, 1, 1, 1)
        self.downSampleGO = QtWidgets.QPushButton(self.downSampleGroupBox)
        self.downSampleGO.setStyleSheet("#downSampleGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#downSampleGO:disabled{\n"
"    background: black;\n"
"}")
        self.downSampleGO.setObjectName("downSampleGO")
        self.gridLayout_5.addWidget(self.downSampleGO, 1, 2, 1, 1)
        self.verticalLayout_3.addWidget(self.downSampleGroupBox)
        self.windowFilterGroupBox = QtWidgets.QGroupBox(self.LoadTab)
        self.windowFilterGroupBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.windowFilterGroupBox.sizePolicy().hasHeightForWidth())
        self.windowFilterGroupBox.setSizePolicy(sizePolicy)
        self.windowFilterGroupBox.setMinimumSize(QtCore.QSize(505, 90))
        self.windowFilterGroupBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.windowFilterGroupBox.setCheckable(True)
        self.windowFilterGroupBox.setObjectName("windowFilterGroupBox")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.windowFilterGroupBox)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.lcdWinDead = QtWidgets.QLCDNumber(self.windowFilterGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdWinDead.sizePolicy().hasHeightForWidth())
        self.lcdWinDead.setSizePolicy(sizePolicy)
        self.lcdWinDead.setStyleSheet("#lcdWinDead {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdWinDead:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdWinDead.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdWinDead.setObjectName("lcdWinDead")
        self.gridLayout_6.addWidget(self.lcdWinDead, 4, 1, 1, 1)
        self.windowFilterGO = QtWidgets.QPushButton(self.windowFilterGroupBox)
        self.windowFilterGO.setStyleSheet("#windowFilterGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#windowFilterGO:disabled{\n"
"    background: black;\n"
"}")
        self.windowFilterGO.setObjectName("windowFilterGO")
        self.gridLayout_6.addWidget(self.windowFilterGO, 4, 3, 1, 1)
        self.label_48 = QtWidgets.QLabel(self.windowFilterGroupBox)
        self.label_48.setObjectName("label_48")
        self.gridLayout_6.addWidget(self.label_48, 1, 0, 1, 1)
        self.windowBandwidthSpinBox = QtWidgets.QDoubleSpinBox(self.windowFilterGroupBox)
        self.windowBandwidthSpinBox.setDecimals(1)
        self.windowBandwidthSpinBox.setMaximum(1000.0)
        self.windowBandwidthSpinBox.setProperty("value", 600.0)
        self.windowBandwidthSpinBox.setObjectName("windowBandwidthSpinBox")
        self.gridLayout_6.addWidget(self.windowBandwidthSpinBox, 1, 1, 2, 1)
        self.label_45 = QtWidgets.QLabel(self.windowFilterGroupBox)
        self.label_45.setObjectName("label_45")
        self.gridLayout_6.addWidget(self.label_45, 0, 0, 1, 1)
        self.label_55 = QtWidgets.QLabel(self.windowFilterGroupBox)
        self.label_55.setObjectName("label_55")
        self.gridLayout_6.addWidget(self.label_55, 4, 0, 1, 1)
        self.windowTypeComboBox = QtWidgets.QComboBox(self.windowFilterGroupBox)
        self.windowTypeComboBox.setObjectName("windowTypeComboBox")
        self.windowTypeComboBox.addItem("")
        self.windowTypeComboBox.addItem("")
        self.windowTypeComboBox.addItem("")
        self.windowTypeComboBox.addItem("")
        self.gridLayout_6.addWidget(self.windowTypeComboBox, 0, 1, 1, 1)
        self.fdDesignPushButton = QtWidgets.QPushButton(self.windowFilterGroupBox)
        self.fdDesignPushButton.setStyleSheet("")
        self.fdDesignPushButton.setObjectName("fdDesignPushButton")
        self.gridLayout_6.addWidget(self.fdDesignPushButton, 1, 3, 1, 1)
        self.verticalLayout_3.addWidget(self.windowFilterGroupBox)
        self.BandPassBox = QtWidgets.QGroupBox(self.LoadTab)
        self.BandPassBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.BandPassBox.sizePolicy().hasHeightForWidth())
        self.BandPassBox.setSizePolicy(sizePolicy)
        self.BandPassBox.setMinimumSize(QtCore.QSize(505, 180))
        self.BandPassBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.BandPassBox.setCheckable(True)
        self.BandPassBox.setChecked(False)
        self.BandPassBox.setObjectName("BandPassBox")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.BandPassBox)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.label_19 = QtWidgets.QLabel(self.BandPassBox)
        self.label_19.setObjectName("label_19")
        self.gridLayout_7.addWidget(self.label_19, 1, 0, 1, 1)
        self.bandPassGO = QtWidgets.QPushButton(self.BandPassBox)
        self.bandPassGO.setStyleSheet("#bandPassGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#bandPassGO:disabled{\n"
"    background: black;\n"
"}")
        self.bandPassGO.setObjectName("bandPassGO")
        self.gridLayout_7.addWidget(self.bandPassGO, 6, 3, 2, 2)
        self.lcdNumberFTauDead = QtWidgets.QLCDNumber(self.BandPassBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberFTauDead.sizePolicy().hasHeightForWidth())
        self.lcdNumberFTauDead.setSizePolicy(sizePolicy)
        self.lcdNumberFTauDead.setStyleSheet("#lcdNumberFTauDead {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberFTauDead:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberFTauDead.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberFTauDead.setObjectName("lcdNumberFTauDead")
        self.gridLayout_7.addWidget(self.lcdNumberFTauDead, 2, 4, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.BandPassBox)
        self.label_18.setObjectName("label_18")
        self.gridLayout_7.addWidget(self.label_18, 1, 2, 1, 1)
        self.label_30 = QtWidgets.QLabel(self.BandPassBox)
        self.label_30.setObjectName("label_30")
        self.gridLayout_7.addWidget(self.label_30, 0, 0, 1, 1)
        self.filterDesignPushButton = QtWidgets.QPushButton(self.BandPassBox)
        self.filterDesignPushButton.setStyleSheet("")
        self.filterDesignPushButton.setObjectName("filterDesignPushButton")
        self.gridLayout_7.addWidget(self.filterDesignPushButton, 4, 3, 2, 2)
        self.stopBandSpinBox = QtWidgets.QDoubleSpinBox(self.BandPassBox)
        self.stopBandSpinBox.setMinimum(100.0)
        self.stopBandSpinBox.setMaximum(1000.0)
        self.stopBandSpinBox.setProperty("value", 280.0)
        self.stopBandSpinBox.setObjectName("stopBandSpinBox")
        self.gridLayout_7.addWidget(self.stopBandSpinBox, 2, 1, 1, 1)
        self.label_32 = QtWidgets.QLabel(self.BandPassBox)
        self.label_32.setObjectName("label_32")
        self.gridLayout_7.addWidget(self.label_32, 5, 0, 1, 1)
        self.passBandSpinBox = QtWidgets.QDoubleSpinBox(self.BandPassBox)
        self.passBandSpinBox.setMinimum(25.0)
        self.passBandSpinBox.setMaximum(500.0)
        self.passBandSpinBox.setSingleStep(5.0)
        self.passBandSpinBox.setProperty("value", 50.0)
        self.passBandSpinBox.setObjectName("passBandSpinBox")
        self.gridLayout_7.addWidget(self.passBandSpinBox, 1, 1, 1, 1)
        self.lcdNumberFilterOrder = QtWidgets.QLCDNumber(self.BandPassBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberFilterOrder.sizePolicy().hasHeightForWidth())
        self.lcdNumberFilterOrder.setSizePolicy(sizePolicy)
        self.lcdNumberFilterOrder.setStyleSheet("#lcdNumberFilterOrder {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberFilterOrder:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberFilterOrder.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberFilterOrder.setObjectName("lcdNumberFilterOrder")
        self.gridLayout_7.addWidget(self.lcdNumberFilterOrder, 1, 4, 1, 1)
        self.gpassSpinBox = QtWidgets.QDoubleSpinBox(self.BandPassBox)
        self.gpassSpinBox.setSuffix("")
        self.gpassSpinBox.setDecimals(3)
        self.gpassSpinBox.setMaximum(1.0)
        self.gpassSpinBox.setSingleStep(0.01)
        self.gpassSpinBox.setProperty("value", 0.01)
        self.gpassSpinBox.setObjectName("gpassSpinBox")
        self.gridLayout_7.addWidget(self.gpassSpinBox, 3, 1, 2, 1)
        self.label_10 = QtWidgets.QLabel(self.BandPassBox)
        self.label_10.setObjectName("label_10")
        self.gridLayout_7.addWidget(self.label_10, 0, 2, 1, 1)
        self.plotBP = QtWidgets.QCheckBox(self.BandPassBox)
        self.plotBP.setEnabled(False)
        self.plotBP.setCheckable(True)
        self.plotBP.setChecked(True)
        self.plotBP.setObjectName("plotBP")
        self.gridLayout_7.addWidget(self.plotBP, 7, 0, 1, 1)
        self.CentralVSpinBox = QtWidgets.QDoubleSpinBox(self.BandPassBox)
        self.CentralVSpinBox.setDecimals(0)
        self.CentralVSpinBox.setMinimum(100.0)
        self.CentralVSpinBox.setMaximum(5001.0)
        self.CentralVSpinBox.setSingleStep(1.0)
        self.CentralVSpinBox.setProperty("value", 1000.0)
        self.CentralVSpinBox.setObjectName("CentralVSpinBox")
        self.gridLayout_7.addWidget(self.CentralVSpinBox, 0, 1, 1, 1)
        self.gstopSpinBox = QtWidgets.QDoubleSpinBox(self.BandPassBox)
        self.gstopSpinBox.setProperty("value", 5.0)
        self.gstopSpinBox.setObjectName("gstopSpinBox")
        self.gridLayout_7.addWidget(self.gstopSpinBox, 5, 1, 2, 1)
        self.label_21 = QtWidgets.QLabel(self.BandPassBox)
        self.label_21.setObjectName("label_21")
        self.gridLayout_7.addWidget(self.label_21, 2, 2, 1, 2)
        self.label_20 = QtWidgets.QLabel(self.BandPassBox)
        self.label_20.setObjectName("label_20")
        self.gridLayout_7.addWidget(self.label_20, 2, 0, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.BandPassBox)
        self.label_22.setObjectName("label_22")
        self.gridLayout_7.addWidget(self.label_22, 3, 0, 1, 1)
        self.fTypeComboBox = QtWidgets.QComboBox(self.BandPassBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.fTypeComboBox.sizePolicy().hasHeightForWidth())
        self.fTypeComboBox.setSizePolicy(sizePolicy)
        self.fTypeComboBox.setMouseTracking(True)
        self.fTypeComboBox.setToolTip("")
        self.fTypeComboBox.setStatusTip("")
        self.fTypeComboBox.setWhatsThis("")
        self.fTypeComboBox.setObjectName("fTypeComboBox")
        self.fTypeComboBox.addItem("")
        self.fTypeComboBox.addItem("")
        self.fTypeComboBox.addItem("")
        self.gridLayout_7.addWidget(self.fTypeComboBox, 0, 3, 1, 2)
        self.verticalLayout_3.addWidget(self.BandPassBox)
        self.sumDataBox = QtWidgets.QGroupBox(self.LoadTab)
        self.sumDataBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sumDataBox.sizePolicy().hasHeightForWidth())
        self.sumDataBox.setSizePolicy(sizePolicy)
        self.sumDataBox.setMinimumSize(QtCore.QSize(505, 100))
        self.sumDataBox.setMaximumSize(QtCore.QSize(505, 200))
        self.sumDataBox.setCheckable(True)
        self.sumDataBox.setObjectName("sumDataBox")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.sumDataBox)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.label_5 = QtWidgets.QLabel(self.sumDataBox)
        self.label_5.setObjectName("label_5")
        self.gridLayout_8.addWidget(self.label_5, 0, 0, 1, 1)
        self.comboBox = QtWidgets.QComboBox(self.sumDataBox)
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.gridLayout_8.addWidget(self.comboBox, 0, 1, 1, 1)
        self.sumDataGO = QtWidgets.QPushButton(self.sumDataBox)
        self.sumDataGO.setMaximumSize(QtCore.QSize(100, 16777215))
        self.sumDataGO.setStyleSheet("#sumDataGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#sumDataGO:disabled{\n"
"    background: black;\n"
"}")
        self.sumDataGO.setObjectName("sumDataGO")
        self.gridLayout_8.addWidget(self.sumDataGO, 1, 1, 1, 1)
        self.verticalLayout_3.addWidget(self.sumDataBox)
        self.ProcTabs.addTab(self.LoadTab, "")
        self.NCTab = QtWidgets.QWidget()
        self.NCTab.setObjectName("NCTab")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.NCTab)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.groupBox_3 = QtWidgets.QGroupBox(self.NCTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setMinimumSize(QtCore.QSize(505, 100))
        self.groupBox_3.setCheckable(True)
        self.groupBox_3.setChecked(False)
        self.groupBox_3.setObjectName("groupBox_3")
        self.harmonicGO = QtWidgets.QPushButton(self.groupBox_3)
        self.harmonicGO.setGeometry(QtCore.QRect(380, 120, 88, 34))
        self.harmonicGO.setObjectName("harmonicGO")
        self.f0Spin = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.f0Spin.setGeometry(QtCore.QRect(160, 120, 71, 32))
        self.f0Spin.setSingleStep(0.1)
        self.f0Spin.setProperty("value", 60.0)
        self.f0Spin.setObjectName("f0Spin")
        self.verticalLayout_5.addWidget(self.groupBox_3)
        self.adaptFDBox = QtWidgets.QGroupBox(self.NCTab)
        self.adaptFDBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.adaptFDBox.sizePolicy().hasHeightForWidth())
        self.adaptFDBox.setSizePolicy(sizePolicy)
        self.adaptFDBox.setMinimumSize(QtCore.QSize(505, 200))
        self.adaptFDBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.adaptFDBox.setCheckable(True)
        self.adaptFDBox.setObjectName("adaptFDBox")
        self.adaptFDGO = QtWidgets.QPushButton(self.adaptFDBox)
        self.adaptFDGO.setGeometry(QtCore.QRect(370, 50, 99, 23))
        self.adaptFDGO.setStyleSheet("#adaptFDGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#adaptFDGO:disabled{\n"
"    background: black;\n"
"}")
        self.adaptFDGO.setObjectName("adaptFDGO")
        self.label_36 = QtWidgets.QLabel(self.adaptFDBox)
        self.label_36.setGeometry(QtCore.QRect(20, 30, 271, 16))
        self.label_36.setObjectName("label_36")
        self.label_56 = QtWidgets.QLabel(self.adaptFDBox)
        self.label_56.setGeometry(QtCore.QRect(20, 50, 281, 16))
        self.label_56.setObjectName("label_56")
        self.verticalLayout_5.addWidget(self.adaptFDBox)
        self.adaptBox = QtWidgets.QGroupBox(self.NCTab)
        self.adaptBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.adaptBox.sizePolicy().hasHeightForWidth())
        self.adaptBox.setSizePolicy(sizePolicy)
        self.adaptBox.setMinimumSize(QtCore.QSize(505, 120))
        self.adaptBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.adaptBox.setFlat(False)
        self.adaptBox.setCheckable(True)
        self.adaptBox.setObjectName("adaptBox")
        self.adaptGO = QtWidgets.QPushButton(self.adaptBox)
        self.adaptGO.setGeometry(QtCore.QRect(370, 90, 99, 23))
        self.adaptGO.setStyleSheet("#adaptGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#adaptGO:disabled{\n"
"    background: black;\n"
"}")
        self.adaptGO.setObjectName("adaptGO")
        self.MTapsSpinBox = QtWidgets.QSpinBox(self.adaptBox)
        self.MTapsSpinBox.setGeometry(QtCore.QRect(150, 30, 71, 22))
        self.MTapsSpinBox.setMaximum(2000)
        self.MTapsSpinBox.setProperty("value", 200)
        self.MTapsSpinBox.setObjectName("MTapsSpinBox")
        self.adaptLambdaSpinBox = QtWidgets.QDoubleSpinBox(self.adaptBox)
        self.adaptLambdaSpinBox.setGeometry(QtCore.QRect(150, 60, 71, 22))
        self.adaptLambdaSpinBox.setMinimum(0.2)
        self.adaptLambdaSpinBox.setMaximum(1.0)
        self.adaptLambdaSpinBox.setProperty("value", 0.99)
        self.adaptLambdaSpinBox.setObjectName("adaptLambdaSpinBox")
        self.label_43 = QtWidgets.QLabel(self.adaptBox)
        self.label_43.setGeometry(QtCore.QRect(10, 32, 71, 16))
        self.label_43.setObjectName("label_43")
        self.label_44 = QtWidgets.QLabel(self.adaptBox)
        self.label_44.setGeometry(QtCore.QRect(10, 62, 131, 16))
        self.label_44.setObjectName("label_44")
        self.label_46 = QtWidgets.QLabel(self.adaptBox)
        self.label_46.setGeometry(QtCore.QRect(10, 92, 111, 16))
        self.label_46.setObjectName("label_46")
        self.adaptTruncateSpinBox = QtWidgets.QDoubleSpinBox(self.adaptBox)
        self.adaptTruncateSpinBox.setGeometry(QtCore.QRect(150, 90, 71, 22))
        self.adaptTruncateSpinBox.setMaximum(1000.0)
        self.adaptTruncateSpinBox.setProperty("value", 800.0)
        self.adaptTruncateSpinBox.setObjectName("adaptTruncateSpinBox")
        self.adaptMuSpinBox = QtWidgets.QDoubleSpinBox(self.adaptBox)
        self.adaptMuSpinBox.setGeometry(QtCore.QRect(370, 30, 81, 22))
        self.adaptMuSpinBox.setDecimals(4)
        self.adaptMuSpinBox.setMinimum(0.0001)
        self.adaptMuSpinBox.setMaximum(0.1)
        self.adaptMuSpinBox.setSingleStep(0.0001)
        self.adaptMuSpinBox.setProperty("value", 0.01)
        self.adaptMuSpinBox.setObjectName("adaptMuSpinBox")
        self.label_51 = QtWidgets.QLabel(self.adaptBox)
        self.label_51.setGeometry(QtCore.QRect(260, 33, 57, 14))
        self.label_51.setObjectName("label_51")
        self.label_52 = QtWidgets.QLabel(self.adaptBox)
        self.label_52.setGeometry(QtCore.QRect(260, 63, 91, 16))
        self.label_52.setObjectName("label_52")
        self.PCAComboBox = QtWidgets.QComboBox(self.adaptBox)
        self.PCAComboBox.setGeometry(QtCore.QRect(370, 60, 79, 22))
        self.PCAComboBox.setObjectName("PCAComboBox")
        self.PCAComboBox.addItem("")
        self.PCAComboBox.addItem("")
        self.verticalLayout_5.addWidget(self.adaptBox)
        self.ProcTabs.addTab(self.NCTab, "")
        self.QCTab = QtWidgets.QWidget()
        self.QCTab.setObjectName("QCTab")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.QCTab)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.qCalcGroupBox = QtWidgets.QGroupBox(self.QCTab)
        self.qCalcGroupBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.qCalcGroupBox.sizePolicy().hasHeightForWidth())
        self.qCalcGroupBox.setSizePolicy(sizePolicy)
        self.qCalcGroupBox.setMinimumSize(QtCore.QSize(505, 100))
        self.qCalcGroupBox.setMaximumSize(QtCore.QSize(505, 150))
        self.qCalcGroupBox.setCheckable(True)
        self.qCalcGroupBox.setObjectName("qCalcGroupBox")
        self.label_8 = QtWidgets.QLabel(self.qCalcGroupBox)
        self.label_8.setGeometry(QtCore.QRect(8, 84, 399, 10))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_8.sizePolicy().hasHeightForWidth())
        self.label_8.setSizePolicy(sizePolicy)
        self.label_8.setMinimumSize(QtCore.QSize(0, 10))
        self.label_8.setMaximumSize(QtCore.QSize(16777215, 10))
        self.label_8.setObjectName("label_8")
        self.calcQGO = QtWidgets.QPushButton(self.qCalcGroupBox)
        self.calcQGO.setGeometry(QtCore.QRect(380, 80, 84, 30))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.calcQGO.sizePolicy().hasHeightForWidth())
        self.calcQGO.setSizePolicy(sizePolicy)
        self.calcQGO.setMinimumSize(QtCore.QSize(80, 30))
        self.calcQGO.setStyleSheet("#calcQGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#calcQGO:disabled{\n"
"    background: black;\n"
"}")
        self.calcQGO.setObjectName("calcQGO")
        self.verticalLayout_6.addWidget(self.qCalcGroupBox)
        self.FDSmartStackGroupBox = QtWidgets.QGroupBox(self.QCTab)
        self.FDSmartStackGroupBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FDSmartStackGroupBox.sizePolicy().hasHeightForWidth())
        self.FDSmartStackGroupBox.setSizePolicy(sizePolicy)
        self.FDSmartStackGroupBox.setMinimumSize(QtCore.QSize(505, 150))
        self.FDSmartStackGroupBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.FDSmartStackGroupBox.setCheckable(True)
        self.FDSmartStackGroupBox.setObjectName("FDSmartStackGroupBox")
        self.outlierTestCB = QtWidgets.QComboBox(self.FDSmartStackGroupBox)
        self.outlierTestCB.setGeometry(QtCore.QRect(90, 65, 78, 25))
        self.outlierTestCB.setObjectName("outlierTestCB")
        self.outlierTestCB.addItem("")
        self.outlierTestCB.addItem("")
        self.label_37 = QtWidgets.QLabel(self.FDSmartStackGroupBox)
        self.label_37.setGeometry(QtCore.QRect(10, 70, 71, 16))
        self.label_37.setObjectName("label_37")
        self.FDSmartStackGO = QtWidgets.QPushButton(self.FDSmartStackGroupBox)
        self.FDSmartStackGO.setGeometry(QtCore.QRect(350, 70, 99, 23))
        self.FDSmartStackGO.setStyleSheet("#FDSmartStackGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#FDSmartStackGO:disabled{\n"
"    background: black;\n"
"}")
        self.FDSmartStackGO.setObjectName("FDSmartStackGO")
        self.MADCutoff = QtWidgets.QDoubleSpinBox(self.FDSmartStackGroupBox)
        self.MADCutoff.setGeometry(QtCore.QRect(90, 90, 121, 22))
        self.MADCutoff.setDecimals(4)
        self.MADCutoff.setMaximum(10.0)
        self.MADCutoff.setProperty("value", 1.48)
        self.MADCutoff.setObjectName("MADCutoff")
        self.verticalLayout_6.addWidget(self.FDSmartStackGroupBox)
        self.qdGroupBox = QtWidgets.QGroupBox(self.QCTab)
        self.qdGroupBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.qdGroupBox.sizePolicy().hasHeightForWidth())
        self.qdGroupBox.setSizePolicy(sizePolicy)
        self.qdGroupBox.setMinimumSize(QtCore.QSize(505, 100))
        self.qdGroupBox.setMaximumSize(QtCore.QSize(505, 200))
        self.qdGroupBox.setCheckable(True)
        self.qdGroupBox.setObjectName("qdGroupBox")
        self.qdGO = QtWidgets.QPushButton(self.qdGroupBox)
        self.qdGO.setGeometry(QtCore.QRect(350, 60, 99, 23))
        self.qdGO.setStyleSheet("#qdGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#qdGO:disabled{\n"
"    background: black;\n"
"}")
        self.qdGO.setObjectName("qdGO")
        self.trimSpin = QtWidgets.QSpinBox(self.qdGroupBox)
        self.trimSpin.setGeometry(QtCore.QRect(90, 30, 91, 28))
        self.trimSpin.setMinimum(0)
        self.trimSpin.setProperty("value", 0)
        self.trimSpin.setObjectName("trimSpin")
        self.label_38 = QtWidgets.QLabel(self.qdGroupBox)
        self.label_38.setGeometry(QtCore.QRect(20, 34, 61, 18))
        self.label_38.setObjectName("label_38")
        self.QDType = QtWidgets.QComboBox(self.qdGroupBox)
        self.QDType.setGeometry(QtCore.QRect(230, 90, 101, 22))
        self.QDType.setObjectName("QDType")
        self.QDType.addItem("")
        self.QDType.addItem("")
        self.QDType.addItem("")
        self.plotQD = QtWidgets.QPushButton(self.qdGroupBox)
        self.plotQD.setEnabled(False)
        self.plotQD.setGeometry(QtCore.QRect(350, 90, 99, 23))
        self.plotQD.setStyleSheet("#plotQD {\n"
"    background: green;\n"
"}\n"
"\n"
"#plotQD:disabled{\n"
"    background: black;\n"
"}")
        self.plotQD.setCheckable(False)
        self.plotQD.setObjectName("plotQD")
        self.verticalLayout_6.addWidget(self.qdGroupBox)
        self.gateBox = QtWidgets.QGroupBox(self.QCTab)
        self.gateBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.gateBox.sizePolicy().hasHeightForWidth())
        self.gateBox.setSizePolicy(sizePolicy)
        self.gateBox.setMinimumSize(QtCore.QSize(505, 200))
        self.gateBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.gateBox.setCheckable(True)
        self.gateBox.setObjectName("gateBox")
        self.gateIntegrateGO = QtWidgets.QPushButton(self.gateBox)
        self.gateIntegrateGO.setGeometry(QtCore.QRect(350, 30, 99, 23))
        self.gateIntegrateGO.setStyleSheet("#gateIntegrateGO {\n"
"    background: green;\n"
"}\n"
"\n"
"#gateIntegrateGO:disabled{\n"
"    background: black;\n"
"}")
        self.gateIntegrateGO.setObjectName("gateIntegrateGO")
        self.GPDspinBox = QtWidgets.QSpinBox(self.gateBox)
        self.GPDspinBox.setGeometry(QtCore.QRect(130, 28, 71, 23))
        self.GPDspinBox.setMinimum(6)
        self.GPDspinBox.setMaximum(30)
        self.GPDspinBox.setProperty("value", 20)
        self.GPDspinBox.setObjectName("GPDspinBox")
        self.label_53 = QtWidgets.QLabel(self.gateBox)
        self.label_53.setGeometry(QtCore.QRect(20, 30, 111, 16))
        self.label_53.setObjectName("label_53")
        self.QDType_2 = QtWidgets.QComboBox(self.gateBox)
        self.QDType_2.setGeometry(QtCore.QRect(230, 60, 101, 22))
        self.QDType_2.setObjectName("QDType_2")
        self.QDType_2.addItem("")
        self.QDType_2.addItem("")
        self.QDType_2.addItem("")
        self.plotGI = QtWidgets.QPushButton(self.gateBox)
        self.plotGI.setEnabled(False)
        self.plotGI.setGeometry(QtCore.QRect(350, 60, 99, 23))
        self.plotGI.setStyleSheet("#plotGI {\n"
"    background: green;\n"
"}\n"
"\n"
"#plotGI:disabled{\n"
"    background: black;\n"
"}")
        self.plotGI.setCheckable(False)
        self.plotGI.setObjectName("plotGI")
        self.verticalLayout_6.addWidget(self.gateBox)
        self.ProcTabs.addTab(self.QCTab, "")
        self.METATab = QtWidgets.QWidget()
        self.METATab.setObjectName("METATab")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.METATab)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBox_4 = QtWidgets.QGroupBox(self.METATab)
        self.groupBox_4.setObjectName("groupBox_4")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.loopTableWidget = QtWidgets.QTableWidget(self.groupBox_4)
        self.loopTableWidget.setObjectName("loopTableWidget")
        self.loopTableWidget.setColumnCount(0)
        self.loopTableWidget.setRowCount(0)
        self.verticalLayout_8.addWidget(self.loopTableWidget)
        self.gridLayout_2.addWidget(self.groupBox_4, 2, 1, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.METATab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(505, 250))
        self.groupBox.setMaximumSize(QtCore.QSize(505, 16777215))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.label_68 = QtWidgets.QLabel(self.groupBox)
        self.label_68.setObjectName("label_68")
        self.gridLayout_10.addWidget(self.label_68, 7, 0, 1, 1)
        self.decSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.decSpinBox.setDecimals(1)
        self.decSpinBox.setMinimum(-90.0)
        self.decSpinBox.setMaximum(90.0)
        self.decSpinBox.setProperty("value", 0.0)
        self.decSpinBox.setObjectName("decSpinBox")
        self.gridLayout_10.addWidget(self.decSpinBox, 5, 2, 1, 1)
        self.timeEdit = QtWidgets.QTimeEdit(self.groupBox)
        self.timeEdit.setCalendarPopup(True)
        self.timeEdit.setObjectName("timeEdit")
        self.gridLayout_10.addWidget(self.timeEdit, 3, 2, 1, 1)
        self.incSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.incSpinBox.setDecimals(1)
        self.incSpinBox.setMinimum(-90.0)
        self.incSpinBox.setMaximum(90.0)
        self.incSpinBox.setProperty("value", 45.0)
        self.incSpinBox.setObjectName("incSpinBox")
        self.gridLayout_10.addWidget(self.incSpinBox, 4, 2, 1, 1)
        self.tempSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.tempSpinBox.setProperty("value", 20.0)
        self.tempSpinBox.setObjectName("tempSpinBox")
        self.gridLayout_10.addWidget(self.tempSpinBox, 1, 2, 1, 1)
        self.label_66 = QtWidgets.QLabel(self.groupBox)
        self.label_66.setObjectName("label_66")
        self.gridLayout_10.addWidget(self.label_66, 5, 0, 1, 2)
        self.label_54 = QtWidgets.QLabel(self.groupBox)
        self.label_54.setObjectName("label_54")
        self.gridLayout_10.addWidget(self.label_54, 1, 0, 1, 2)
        self.label_57 = QtWidgets.QLabel(self.groupBox)
        self.label_57.setObjectName("label_57")
        self.gridLayout_10.addWidget(self.label_57, 2, 0, 1, 2)
        self.label_67 = QtWidgets.QLabel(self.groupBox)
        self.label_67.setObjectName("label_67")
        self.gridLayout_10.addWidget(self.label_67, 4, 0, 1, 2)
        self.locEdit = QtWidgets.QLineEdit(self.groupBox)
        self.locEdit.setObjectName("locEdit")
        self.gridLayout_10.addWidget(self.locEdit, 0, 2, 1, 1)
        self.dateEdit = QtWidgets.QDateEdit(self.groupBox)
        self.dateEdit.setCalendarPopup(True)
        self.dateEdit.setDate(QtCore.QDate(2019, 1, 1))
        self.dateEdit.setObjectName("dateEdit")
        self.gridLayout_10.addWidget(self.dateEdit, 2, 2, 1, 1)
        self.label_64 = QtWidgets.QLabel(self.groupBox)
        self.label_64.setObjectName("label_64")
        self.gridLayout_10.addWidget(self.label_64, 3, 0, 1, 2)
        self.intensitySpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.intensitySpinBox.setDecimals(1)
        self.intensitySpinBox.setMaximum(80000.0)
        self.intensitySpinBox.setProperty("value", 50000.0)
        self.intensitySpinBox.setObjectName("intensitySpinBox")
        self.gridLayout_10.addWidget(self.intensitySpinBox, 7, 2, 1, 1)
        self.label_62 = QtWidgets.QLabel(self.groupBox)
        self.label_62.setObjectName("label_62")
        self.gridLayout_10.addWidget(self.label_62, 0, 0, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox, 0, 1, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.METATab)
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.groupBox_5)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.txtComments = QtWidgets.QTextBrowser(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtComments.sizePolicy().hasHeightForWidth())
        self.txtComments.setSizePolicy(sizePolicy)
        self.txtComments.setMinimumSize(QtCore.QSize(490, 0))
        self.txtComments.setMaximumSize(QtCore.QSize(490, 420))
        self.txtComments.setReadOnly(False)
        self.txtComments.setObjectName("txtComments")
        self.verticalLayout_7.addWidget(self.txtComments)
        self.gridLayout_2.addWidget(self.groupBox_5, 1, 1, 1, 1)
        self.ProcTabs.addTab(self.METATab, "")
        self.KernTab = QtWidgets.QWidget()
        self.KernTab.setObjectName("KernTab")
        self.groupBox_2 = QtWidgets.QGroupBox(self.KernTab)
        self.groupBox_2.setGeometry(QtCore.QRect(30, 10, 371, 301))
        self.groupBox_2.setObjectName("groupBox_2")
        self.spinBox = QtWidgets.QSpinBox(self.groupBox_2)
        self.spinBox.setGeometry(QtCore.QRect(120, 30, 49, 29))
        self.spinBox.setObjectName("spinBox")
        self.spinBox_2 = QtWidgets.QSpinBox(self.groupBox_2)
        self.spinBox_2.setGeometry(QtCore.QRect(120, 70, 49, 29))
        self.spinBox_2.setObjectName("spinBox_2")
        self.doubleSpinBox_7 = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.doubleSpinBox_7.setGeometry(QtCore.QRect(280, 70, 70, 29))
        self.doubleSpinBox_7.setObjectName("doubleSpinBox_7")
        self.label_70 = QtWidgets.QLabel(self.groupBox_2)
        self.label_70.setGeometry(QtCore.QRect(21, 34, 81, 20))
        self.label_70.setObjectName("label_70")
        self.label_71 = QtWidgets.QLabel(self.groupBox_2)
        self.label_71.setGeometry(QtCore.QRect(20, 75, 81, 20))
        self.label_71.setObjectName("label_71")
        self.label_72 = QtWidgets.QLabel(self.groupBox_2)
        self.label_72.setGeometry(QtCore.QRect(187, 75, 81, 20))
        self.label_72.setObjectName("label_72")
        self.doubleSpinBox_6 = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.doubleSpinBox_6.setGeometry(QtCore.QRect(210, 260, 141, 29))
        self.doubleSpinBox_6.setObjectName("doubleSpinBox_6")
        self.doubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.doubleSpinBox.setGeometry(QtCore.QRect(10, 160, 171, 29))
        self.doubleSpinBox.setObjectName("doubleSpinBox")
        self.doubleSpinBox_3 = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.doubleSpinBox_3.setGeometry(QtCore.QRect(10, 210, 171, 31))
        self.doubleSpinBox_3.setObjectName("doubleSpinBox_3")
        self.doubleSpinBox_5 = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.doubleSpinBox_5.setGeometry(QtCore.QRect(210, 210, 141, 29))
        self.doubleSpinBox_5.setObjectName("doubleSpinBox_5")
        self.doubleSpinBox_4 = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.doubleSpinBox_4.setGeometry(QtCore.QRect(210, 160, 141, 29))
        self.doubleSpinBox_4.setObjectName("doubleSpinBox_4")
        self.doubleSpinBox_2 = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.doubleSpinBox_2.setGeometry(QtCore.QRect(10, 260, 171, 29))
        self.doubleSpinBox_2.setObjectName("doubleSpinBox_2")
        self.label_2 = QtWidgets.QLabel(self.groupBox_2)
        self.label_2.setGeometry(QtCore.QRect(10, 130, 63, 20))
        self.label_2.setObjectName("label_2")
        self.label_73 = QtWidgets.QLabel(self.groupBox_2)
        self.label_73.setGeometry(QtCore.QRect(210, 130, 63, 20))
        self.label_73.setObjectName("label_73")
        self.layerTableWidget = QtWidgets.QTableWidget(self.KernTab)
        self.layerTableWidget.setGeometry(QtCore.QRect(30, 320, 351, 501))
        self.layerTableWidget.setObjectName("layerTableWidget")
        self.layerTableWidget.setColumnCount(0)
        self.layerTableWidget.setRowCount(0)
        self.ProcTabs.addTab(self.KernTab, "")
        self.ModelTab = QtWidgets.QWidget()
        self.ModelTab.setObjectName("ModelTab")
        self.toolBox = QtWidgets.QToolBox(self.ModelTab)
        self.toolBox.setGeometry(QtCore.QRect(40, 80, 411, 141))
        self.toolBox.setObjectName("toolBox")
        self.page = QtWidgets.QWidget()
        self.page.setGeometry(QtCore.QRect(0, 0, 96, 26))
        self.page.setObjectName("page")
        self.toolBox.addItem(self.page, "")
        self.page_2 = QtWidgets.QWidget()
        self.page_2.setGeometry(QtCore.QRect(0, 0, 411, 77))
        self.page_2.setObjectName("page_2")
        self.toolBox.addItem(self.page_2, "")
        self.ProcTabs.addTab(self.ModelTab, "")
        self.InvertTab = QtWidgets.QWidget()
        self.InvertTab.setObjectName("InvertTab")
        self.invertButton = QtWidgets.QPushButton(self.InvertTab)
        self.invertButton.setGeometry(QtCore.QRect(130, 140, 311, 141))
        self.invertButton.setStyleSheet("#invertButton {\n"
"font-size:29pt;\n"
"font-weight: bold;\n"
"color: white;\n"
"background: red;\n"
"}")
        self.invertButton.setObjectName("invertButton")
        self.ProcTabs.addTab(self.InvertTab, "")
        self.AppraiseTab = QtWidgets.QWidget()
        self.AppraiseTab.setObjectName("AppraiseTab")
        self.ProcTabs.addTab(self.AppraiseTab, "")
        self.LogTab = QtWidgets.QWidget()
        self.LogTab.setObjectName("LogTab")
        self.logTextBrowser = QtWidgets.QTextBrowser(self.LogTab)
        self.logTextBrowser.setGeometry(QtCore.QRect(10, 30, 921, 821))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.logTextBrowser.sizePolicy().hasHeightForWidth())
        self.logTextBrowser.setSizePolicy(sizePolicy)
        self.logTextBrowser.setObjectName("logTextBrowser")
        self.label_74 = QtWidgets.QLabel(self.LogTab)
        self.label_74.setGeometry(QtCore.QRect(420, 10, 121, 20))
        self.label_74.setObjectName("label_74")
        self.ProcTabs.addTab(self.LogTab, "")
        self.verticalLayout_2.addWidget(self.ProcTabs)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.gridLayout.addWidget(self.scrollArea, 0, 1, 1, 1)
        self.groupBoxPlot = QtWidgets.QGroupBox(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxPlot.sizePolicy().hasHeightForWidth())
        self.groupBoxPlot.setSizePolicy(sizePolicy)
        self.groupBoxPlot.setMinimumSize(QtCore.QSize(500, 0))
        self.groupBoxPlot.setTitle("")
        self.groupBoxPlot.setObjectName("groupBoxPlot")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBoxPlot)
        self.verticalLayout.setObjectName("verticalLayout")
        self.mplwidget = MyDynamicMplCanvas(self.groupBoxPlot)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mplwidget.sizePolicy().hasHeightForWidth())
        self.mplwidget.setSizePolicy(sizePolicy)
        self.mplwidget.setMinimumSize(QtCore.QSize(500, 300))
        self.mplwidget.setObjectName("mplwidget")
        self.verticalLayout.addWidget(self.mplwidget)
        self.mplwidget_navigator = MyDynamicMplCanvasNavigator(self.groupBoxPlot)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mplwidget_navigator.sizePolicy().hasHeightForWidth())
        self.mplwidget_navigator.setSizePolicy(sizePolicy)
        self.mplwidget_navigator.setMinimumSize(QtCore.QSize(460, 38))
        self.mplwidget_navigator.setObjectName("mplwidget_navigator")
        self.verticalLayout.addWidget(self.mplwidget_navigator)
        self.headerFileBox = QtWidgets.QGroupBox(self.groupBoxPlot)
        self.headerFileBox.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.headerFileBox.sizePolicy().hasHeightForWidth())
        self.headerFileBox.setSizePolicy(sizePolicy)
        self.headerFileBox.setMinimumSize(QtCore.QSize(460, 50))
        self.headerFileBox.setAcceptDrops(False)
        self.headerFileBox.setAutoFillBackground(False)
        self.headerFileBox.setFlat(False)
        self.headerFileBox.setCheckable(True)
        self.headerFileBox.setObjectName("headerFileBox")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.headerFileBox)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.headerFileTextBrowser = QtWidgets.QTextBrowser(self.headerFileBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.headerFileTextBrowser.sizePolicy().hasHeightForWidth())
        self.headerFileTextBrowser.setSizePolicy(sizePolicy)
        self.headerFileTextBrowser.setMinimumSize(QtCore.QSize(0, 23))
        self.headerFileTextBrowser.setMaximumSize(QtCore.QSize(16777215, 23))
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setItalic(True)
        self.headerFileTextBrowser.setFont(font)
        self.headerFileTextBrowser.setObjectName("headerFileTextBrowser")
        self.verticalLayout_4.addWidget(self.headerFileTextBrowser)
        self.headerBox2 = QtWidgets.QGroupBox(self.headerFileBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.headerBox2.sizePolicy().hasHeightForWidth())
        self.headerBox2.setSizePolicy(sizePolicy)
        self.headerBox2.setMinimumSize(QtCore.QSize(540, 0))
        self.headerBox2.setTitle("")
        self.headerBox2.setObjectName("headerBox2")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.headerBox2)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_6 = QtWidgets.QLabel(self.headerBox2)
        self.label_6.setObjectName("label_6")
        self.gridLayout_3.addWidget(self.label_6, 0, 0, 1, 1)
        self.lcdNumberNuTx = QtWidgets.QLCDNumber(self.headerBox2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberNuTx.sizePolicy().hasHeightForWidth())
        self.lcdNumberNuTx.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.lcdNumberNuTx.setFont(font)
        self.lcdNumberNuTx.setWhatsThis("")
        self.lcdNumberNuTx.setAutoFillBackground(False)
        self.lcdNumberNuTx.setStyleSheet("#lcdNumberNuTx {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberNuTx:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberNuTx.setFrameShadow(QtWidgets.QFrame.Raised)
        self.lcdNumberNuTx.setLineWidth(1)
        self.lcdNumberNuTx.setMidLineWidth(0)
        self.lcdNumberNuTx.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberNuTx.setProperty("value", 0.0)
        self.lcdNumberNuTx.setObjectName("lcdNumberNuTx")
        self.gridLayout_3.addWidget(self.lcdNumberNuTx, 0, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.headerBox2)
        self.label_4.setObjectName("label_4")
        self.gridLayout_3.addWidget(self.label_4, 0, 2, 1, 1)
        self.pulseTypeTextBrowser = QtWidgets.QTextBrowser(self.headerBox2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pulseTypeTextBrowser.sizePolicy().hasHeightForWidth())
        self.pulseTypeTextBrowser.setSizePolicy(sizePolicy)
        self.pulseTypeTextBrowser.setMinimumSize(QtCore.QSize(64, 23))
        self.pulseTypeTextBrowser.setMaximumSize(QtCore.QSize(64, 23))
        font = QtGui.QFont()
        font.setItalic(True)
        self.pulseTypeTextBrowser.setFont(font)
        self.pulseTypeTextBrowser.setAcceptDrops(True)
        self.pulseTypeTextBrowser.setToolTip("")
        self.pulseTypeTextBrowser.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.pulseTypeTextBrowser.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.pulseTypeTextBrowser.setObjectName("pulseTypeTextBrowser")
        self.gridLayout_3.addWidget(self.pulseTypeTextBrowser, 0, 3, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.headerBox2)
        self.label_9.setObjectName("label_9")
        self.gridLayout_3.addWidget(self.label_9, 1, 0, 1, 1)
        self.lcdNumberNQ = QtWidgets.QLCDNumber(self.headerBox2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberNQ.sizePolicy().hasHeightForWidth())
        self.lcdNumberNQ.setSizePolicy(sizePolicy)
        self.lcdNumberNQ.setStyleSheet("#lcdNumberNQ {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberNQ:disabled{\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberNQ.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberNQ.setObjectName("lcdNumberNQ")
        self.gridLayout_3.addWidget(self.lcdNumberNQ, 1, 1, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.headerBox2)
        self.label_13.setObjectName("label_13")
        self.gridLayout_3.addWidget(self.label_13, 1, 2, 1, 1)
        self.lcdNumberTauDelay = QtWidgets.QLCDNumber(self.headerBox2)
        self.lcdNumberTauDelay.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberTauDelay.sizePolicy().hasHeightForWidth())
        self.lcdNumberTauDelay.setSizePolicy(sizePolicy)
        self.lcdNumberTauDelay.setMaximumSize(QtCore.QSize(16777215, 23))
        self.lcdNumberTauDelay.setStyleSheet("#lcdNumberTauDelay {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTauDelay:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberTauDelay.setLineWidth(1)
        self.lcdNumberTauDelay.setMidLineWidth(0)
        self.lcdNumberTauDelay.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberTauDelay.setObjectName("lcdNumberTauDelay")
        self.gridLayout_3.addWidget(self.lcdNumberTauDelay, 1, 3, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.headerBox2)
        self.label_7.setObjectName("label_7")
        self.gridLayout_3.addWidget(self.label_7, 2, 0, 1, 1)
        self.lcdNumberTauPulse1 = QtWidgets.QLCDNumber(self.headerBox2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberTauPulse1.sizePolicy().hasHeightForWidth())
        self.lcdNumberTauPulse1.setSizePolicy(sizePolicy)
        self.lcdNumberTauPulse1.setStyleSheet("#lcdNumberTauPulse1 {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTauPulse1:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberTauPulse1.setFrameShadow(QtWidgets.QFrame.Raised)
        self.lcdNumberTauPulse1.setLineWidth(1)
        self.lcdNumberTauPulse1.setMidLineWidth(0)
        self.lcdNumberTauPulse1.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberTauPulse1.setObjectName("lcdNumberTauPulse1")
        self.gridLayout_3.addWidget(self.lcdNumberTauPulse1, 2, 1, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.headerBox2)
        self.label_17.setObjectName("label_17")
        self.gridLayout_3.addWidget(self.label_17, 2, 2, 1, 1)
        self.lcdNumberFID1Length = QtWidgets.QLCDNumber(self.headerBox2)
        self.lcdNumberFID1Length.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberFID1Length.sizePolicy().hasHeightForWidth())
        self.lcdNumberFID1Length.setSizePolicy(sizePolicy)
        self.lcdNumberFID1Length.setMaximumSize(QtCore.QSize(16777215, 23))
        self.lcdNumberFID1Length.setStyleSheet("#lcdNumberFID1Length {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberFID1Length:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberFID1Length.setLineWidth(1)
        self.lcdNumberFID1Length.setMidLineWidth(0)
        self.lcdNumberFID1Length.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberFID1Length.setObjectName("lcdNumberFID1Length")
        self.gridLayout_3.addWidget(self.lcdNumberFID1Length, 2, 3, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.headerBox2)
        self.label_16.setObjectName("label_16")
        self.gridLayout_3.addWidget(self.label_16, 3, 0, 1, 1)
        self.lcdNumberTauPulse2 = QtWidgets.QLCDNumber(self.headerBox2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberTauPulse2.sizePolicy().hasHeightForWidth())
        self.lcdNumberTauPulse2.setSizePolicy(sizePolicy)
        self.lcdNumberTauPulse2.setStyleSheet("#lcdNumberTauPulse2 {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTauPulse2:disabled{\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberTauPulse2.setLineWidth(1)
        self.lcdNumberTauPulse2.setMidLineWidth(0)
        self.lcdNumberTauPulse2.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberTauPulse2.setObjectName("lcdNumberTauPulse2")
        self.gridLayout_3.addWidget(self.lcdNumberTauPulse2, 3, 1, 1, 1)
        self.label_39 = QtWidgets.QLabel(self.headerBox2)
        self.label_39.setObjectName("label_39")
        self.gridLayout_3.addWidget(self.label_39, 3, 2, 1, 1)
        self.lcdNumberFID2Length = QtWidgets.QLCDNumber(self.headerBox2)
        self.lcdNumberFID2Length.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberFID2Length.sizePolicy().hasHeightForWidth())
        self.lcdNumberFID2Length.setSizePolicy(sizePolicy)
        self.lcdNumberFID2Length.setMaximumSize(QtCore.QSize(16777215, 23))
        self.lcdNumberFID2Length.setStyleSheet("#lcdNumberFID2Length {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberFID2Length:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberFID2Length.setLineWidth(1)
        self.lcdNumberFID2Length.setMidLineWidth(0)
        self.lcdNumberFID2Length.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberFID2Length.setObjectName("lcdNumberFID2Length")
        self.gridLayout_3.addWidget(self.lcdNumberFID2Length, 3, 3, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.headerBox2)
        self.label_15.setObjectName("label_15")
        self.gridLayout_3.addWidget(self.label_15, 4, 0, 1, 1)
        self.lcdNumberSampFreq = QtWidgets.QLCDNumber(self.headerBox2)
        self.lcdNumberSampFreq.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberSampFreq.sizePolicy().hasHeightForWidth())
        self.lcdNumberSampFreq.setSizePolicy(sizePolicy)
        self.lcdNumberSampFreq.setStyleSheet("#lcdNumberSampFreq {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberSampFreq:disabled{\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberSampFreq.setLineWidth(1)
        self.lcdNumberSampFreq.setMidLineWidth(0)
        self.lcdNumberSampFreq.setDigitCount(5)
        self.lcdNumberSampFreq.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberSampFreq.setObjectName("lcdNumberSampFreq")
        self.gridLayout_3.addWidget(self.lcdNumberSampFreq, 4, 1, 1, 1)
        self.label_40 = QtWidgets.QLabel(self.headerBox2)
        self.label_40.setObjectName("label_40")
        self.gridLayout_3.addWidget(self.label_40, 4, 2, 1, 1)
        self.lcdNumberResampFreq = QtWidgets.QLCDNumber(self.headerBox2)
        self.lcdNumberResampFreq.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberResampFreq.sizePolicy().hasHeightForWidth())
        self.lcdNumberResampFreq.setSizePolicy(sizePolicy)
        self.lcdNumberResampFreq.setStyleSheet("#lcdNumberResampFreq {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberResampFreq:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberResampFreq.setLineWidth(1)
        self.lcdNumberResampFreq.setMidLineWidth(0)
        self.lcdNumberResampFreq.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberResampFreq.setObjectName("lcdNumberResampFreq")
        self.gridLayout_3.addWidget(self.lcdNumberResampFreq, 4, 3, 1, 1)
        self.label_14 = QtWidgets.QLabel(self.headerBox2)
        self.label_14.setObjectName("label_14")
        self.gridLayout_3.addWidget(self.label_14, 5, 0, 1, 1)
        self.lcdNumberTuneuF = QtWidgets.QLCDNumber(self.headerBox2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberTuneuF.sizePolicy().hasHeightForWidth())
        self.lcdNumberTuneuF.setSizePolicy(sizePolicy)
        self.lcdNumberTuneuF.setStyleSheet("#lcdNumberTuneuF {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTuneuF:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdNumberTuneuF.setLineWidth(1)
        self.lcdNumberTuneuF.setMidLineWidth(0)
        self.lcdNumberTuneuF.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdNumberTuneuF.setObjectName("lcdNumberTuneuF")
        self.gridLayout_3.addWidget(self.lcdNumberTuneuF, 5, 1, 1, 1)
        self.label_47 = QtWidgets.QLabel(self.headerBox2)
        self.label_47.setObjectName("label_47")
        self.gridLayout_3.addWidget(self.label_47, 5, 2, 1, 1)
        self.lcdTotalDeadTime = QtWidgets.QLCDNumber(self.headerBox2)
        self.lcdTotalDeadTime.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdTotalDeadTime.sizePolicy().hasHeightForWidth())
        self.lcdTotalDeadTime.setSizePolicy(sizePolicy)
        self.lcdTotalDeadTime.setStyleSheet("#lcdTotalDeadTime {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdTotalDeadTime:disabled {\n"
"color: grey;\n"
"background: dark grey;\n"
"}")
        self.lcdTotalDeadTime.setLineWidth(1)
        self.lcdTotalDeadTime.setMidLineWidth(0)
        self.lcdTotalDeadTime.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.lcdTotalDeadTime.setObjectName("lcdTotalDeadTime")
        self.gridLayout_3.addWidget(self.lcdTotalDeadTime, 5, 3, 1, 1)
        self.verticalLayout_4.addWidget(self.headerBox2)
        self.verticalLayout.addWidget(self.headerFileBox)
        self.gridLayout.addWidget(self.groupBoxPlot, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1142, 30))
        self.menubar.setObjectName("menubar")
        self.menuOpen_GMR_RAW_Header = QtWidgets.QMenu(self.menubar)
        self.menuOpen_GMR_RAW_Header.setObjectName("menuOpen_GMR_RAW_Header")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuProcessing = QtWidgets.QMenu(self.menubar)
        self.menuProcessing.setObjectName("menuProcessing")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionOpen_GMR = QtWidgets.QAction(MainWindow)
        self.actionOpen_GMR.setObjectName("actionOpen_GMR")
        self.actionOpen_Preprocessed_Dataset = QtWidgets.QAction(MainWindow)
        self.actionOpen_Preprocessed_Dataset.setObjectName("actionOpen_Preprocessed_Dataset")
        self.actionOpen_VC_Preprocessed_dataset = QtWidgets.QAction(MainWindow)
        self.actionOpen_VC_Preprocessed_dataset.setObjectName("actionOpen_VC_Preprocessed_dataset")
        self.actionSave_Preprocessed_Dataset = QtWidgets.QAction(MainWindow)
        self.actionSave_Preprocessed_Dataset.setObjectName("actionSave_Preprocessed_Dataset")
        self.actionExport_Preprocessed_Dataset = QtWidgets.QAction(MainWindow)
        self.actionExport_Preprocessed_Dataset.setObjectName("actionExport_Preprocessed_Dataset")
        self.actionClose = QtWidgets.QAction(MainWindow)
        self.actionClose.setObjectName("actionClose")
        self.actionAboutAkvo = QtWidgets.QAction(MainWindow)
        self.actionAboutAkvo.setObjectName("actionAboutAkvo")
        self.actionPreprocessing = QtWidgets.QAction(MainWindow)
        self.actionPreprocessing.setCheckable(True)
        self.actionPreprocessing.setChecked(True)
        self.actionPreprocessing.setObjectName("actionPreprocessing")
        self.actionModelling = QtWidgets.QAction(MainWindow)
        self.actionModelling.setCheckable(True)
        self.actionModelling.setObjectName("actionModelling")
        self.actionInversion = QtWidgets.QAction(MainWindow)
        self.actionInversion.setCheckable(True)
        self.actionInversion.setObjectName("actionInversion")
        self.menuOpen_GMR_RAW_Header.addAction(self.actionOpen_GMR)
        self.menuOpen_GMR_RAW_Header.addSeparator()
        self.menuOpen_GMR_RAW_Header.addAction(self.actionOpen_Preprocessed_Dataset)
        self.menuOpen_GMR_RAW_Header.addAction(self.actionOpen_VC_Preprocessed_dataset)
        self.menuOpen_GMR_RAW_Header.addSeparator()
        self.menuOpen_GMR_RAW_Header.addAction(self.actionSave_Preprocessed_Dataset)
        self.menuOpen_GMR_RAW_Header.addAction(self.actionExport_Preprocessed_Dataset)
        self.menuOpen_GMR_RAW_Header.addSeparator()
        self.menuOpen_GMR_RAW_Header.addAction(self.actionClose)
        self.menuHelp.addAction(self.actionAboutAkvo)
        self.menuProcessing.addAction(self.actionPreprocessing)
        self.menuProcessing.addAction(self.actionModelling)
        self.menuProcessing.addAction(self.actionInversion)
        self.menubar.addAction(self.menuOpen_GMR_RAW_Header.menuAction())
        self.menubar.addAction(self.menuProcessing.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.ProcTabs.setCurrentIndex(0)
        self.PCAComboBox.setCurrentIndex(1)
        self.toolBox.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.inputRAWParametersBox.setTitle(_translate("MainWindow", "Input parameters"))
        self.label.setText(_translate("MainWindow", "Stacks"))
        self.stacksLineEdit.setPlaceholderText(_translate("MainWindow", "required"))
        self.label_24.setText(_translate("MainWindow", "Dead time [ms]"))
        self.DeadTimeSpinBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>This is the instrument dead time that is used. You may remove additonal or less dead time as an option. By default Akvo uses the recommended instrument dead times.</p></body></html>"))
        self.label_23.setText(_translate("MainWindow", "Data Chs."))
        self.dataChanLineEdit.setToolTip(_translate("MainWindow", "<html><head/><body><p>Set the data channels that you would like processed.</p><p>This must be a valid set of numpy array indices. Remember that Python uses non end-inclusive indexing. </p><p>So things like [1:3] will use channels 1 and 2</p><p>Any list of valid indices will be accepted, but they must be comma seperated. </p></body></html>"))
        self.dataChanLineEdit.setPlaceholderText(_translate("MainWindow", "required"))
        self.label_28.setText(_translate("MainWindow", "Reference Chs."))
        self.refChanLineEdit.setToolTip(_translate("MainWindow", "<html><head/><body><p>Set the reference channels that you would like processed.</p><p>This must be a valid set of numpy array indices. Remember that Python uses non end-inclusive indexing. </p><p>So things like [1:3] will use channels 1 and 2</p><p>Any list of valid indices will be accepted, but they must be comma seperated. </p><p>Optionally no reference channels are allowed, just leave this field black so it says none</p></body></html>"))
        self.refChanLineEdit.setPlaceholderText(_translate("MainWindow", "none"))
        self.label_29.setText(_translate("MainWindow", "Process FID"))
        self.FIDProcComboBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>For T1 or CPMG pulses, which pulse(s) would you like to process. Note that for very short delay T1 pulses, the first pulse may be disabled. </p></body></html>"))
        self.plotImportCheckBox.setText(_translate("MainWindow", " Plot RAW"))
        self.loadDataPushButton.setText(_translate("MainWindow", "Load Data"))
        self.downSampleGroupBox.setTitle(_translate("MainWindow", "Downsample and truncate (anti-alias)"))
        self.label_3.setText(_translate("MainWindow", "Truncate [ms]"))
        self.truncateSpinBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>Set the final length of your processed record. Note that the use of Adaptive filtering allows for the removal of additional late times. If you do not wish to truncate, leave as 0.</p></body></html>"))
        self.label_12.setText(_translate("MainWindow", "Downsample factor"))
        self.downSampleGO.setText(_translate("MainWindow", "GO"))
        self.windowFilterGroupBox.setTitle(_translate("MainWindow", "FD Window Filter (Central freq from IIR Band-Pass)"))
        self.windowFilterGO.setText(_translate("MainWindow", "GO"))
        self.label_48.setText(_translate("MainWindow", "Width [Hz]"))
        self.label_45.setText(_translate("MainWindow", "Type"))
        self.label_55.setText(_translate("MainWindow", "dead time [ms]"))
        self.windowTypeComboBox.setItemText(0, _translate("MainWindow", "Hamming"))
        self.windowTypeComboBox.setItemText(1, _translate("MainWindow", "Hanning"))
        self.windowTypeComboBox.setItemText(2, _translate("MainWindow", "Flat top"))
        self.windowTypeComboBox.setItemText(3, _translate("MainWindow", "Rectangular"))
        self.fdDesignPushButton.setText(_translate("MainWindow", "design"))
        self.BandPassBox.setTitle(_translate("MainWindow", "IIR Band-Pass Filter"))
        self.label_19.setText(_translate("MainWindow", "Pass Band [Hz]"))
        self.bandPassGO.setText(_translate("MainWindow", "GO"))
        self.label_18.setText(_translate("MainWindow", "Order"))
        self.label_30.setText(_translate("MainWindow", "Central ν Hz"))
        self.filterDesignPushButton.setText(_translate("MainWindow", "design"))
        self.label_32.setText(_translate("MainWindow", "gstop [dB]"))
        self.label_10.setText(_translate("MainWindow", "Type"))
        self.plotBP.setText(_translate("MainWindow", " Plot "))
        self.CentralVSpinBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>In case of off-resonant transmitter pulse, you can set the central frequency that will be used for all processing. This has the biggest impact on the band-pass filter, and the frequencies used in inversion. </p></body></html>"))
        self.label_21.setText(_translate("MainWindow", "dead time [ms]"))
        self.label_20.setText(_translate("MainWindow", "Stop Band [Hz]"))
        self.label_22.setText(_translate("MainWindow", "gpass [dB]"))
        self.fTypeComboBox.setAccessibleDescription(_translate("MainWindow", "Hello"))
        self.fTypeComboBox.setItemText(0, _translate("MainWindow", "Butterworth"))
        self.fTypeComboBox.setItemText(1, _translate("MainWindow", "Chebychev Type II"))
        self.fTypeComboBox.setItemText(2, _translate("MainWindow", "Elliptic"))
        self.sumDataBox.setTitle(_translate("MainWindow", "Combine (sum) data channels"))
        self.label_5.setText(_translate("MainWindow", "Type"))
        self.comboBox.setItemText(0, _translate("MainWindow", "sum"))
        self.comboBox.setItemText(1, _translate("MainWindow", "difference"))
        self.sumDataGO.setToolTip(_translate("MainWindow", "<html><head/><body><p>For some types of multichannel data, the channels can be summed into composite channels. This method sums all channels down to a recursion level of 2.  For single loop datasets do not use this method.  </p></body></html>"))
        self.sumDataGO.setText(_translate("MainWindow", "GO"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.LoadTab), _translate("MainWindow", "Load"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Model-based harmonic removal"))
        self.harmonicGO.setText(_translate("MainWindow", "PushButton"))
        self.adaptFDBox.setTitle(_translate("MainWindow", "FD (static transfer function) Noise cancellation"))
        self.adaptFDGO.setText(_translate("MainWindow", "GO"))
        self.label_36.setText(_translate("MainWindow", "Utilizes a window filter (as defined above) "))
        self.label_56.setText(_translate("MainWindow", "Uses central v from Band-pass filter"))
        self.adaptBox.setTitle(_translate("MainWindow", "Time-domain RLS Active Noise Suppresion"))
        self.adaptGO.setText(_translate("MainWindow", "GO"))
        self.MTapsSpinBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of taps in the time-domain filter</p></body></html>"))
        self.adaptLambdaSpinBox.setToolTip(_translate("MainWindow", "Forgetting factor, how quickly does the filter adapt."))
        self.label_43.setText(_translate("MainWindow", "Filter Taps"))
        self.label_44.setText(_translate("MainWindow", "Forgetting factor (λ)"))
        self.label_46.setText(_translate("MainWindow", "Truncate [ms]"))
        self.adaptTruncateSpinBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>This filter is a time-domain filter that takes some time to get going. Time-domain filters do a better job compared to frequency-domain filters in the presence of non-stationary noise. </p><p>The filter is run backwards, so often the late times will not be cancelled as well. You may trim records off the back using this input. </p></body></html>"))
        self.adaptTruncateSpinBox.setWhatsThis(_translate("MainWindow", "<html><head/><body><p>This filter is a time-domain filter that takes some time to get going. Time-domain filters do a better job compared to frequency-domain filters in the presence of non-stationary noise.  </p><p>The filter is run backwards, so often the late times will not be cancelled as well. You may trim records off the back using this input. </p></body></html>"))
        self.label_51.setText(_translate("MainWindow", "Mu"))
        self.label_52.setText(_translate("MainWindow", "PCA on ref"))
        self.PCAComboBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>Perform priciple component analysis on the reference channels? If <span style=\" font-weight:600;\">yes</span>, PCA will performed on the reference channels and the rotated channels will be used for noise cancelation rather than the raw noise channels. In the case of multiple noise sources where one dominantes across channels, better performance can be realized.</p></body></html>"))
        self.PCAComboBox.setItemText(0, _translate("MainWindow", "Yes"))
        self.PCAComboBox.setItemText(1, _translate("MainWindow", "No"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.NCTab), _translate("MainWindow", "NC"))
        self.ProcTabs.setTabToolTip(self.ProcTabs.indexOf(self.NCTab), _translate("MainWindow", "<html><head/><body><p>This tab contains noise cancellation algorithms. The frequency-domain algorithm is often less effective than the time domain approach. We often discourage using the frequency domain algorithm. </p></body></html>"))
        self.qCalcGroupBox.setTitle(_translate("MainWindow", "Pulse Moment Calculation "))
        self.label_8.setText(_translate("MainWindow", "Fourier-based calculation"))
        self.calcQGO.setText(_translate("MainWindow", "GO"))
        self.FDSmartStackGroupBox.setTitle(_translate("MainWindow", "TD SmartStac&k^TM"))
        self.outlierTestCB.setItemText(0, _translate("MainWindow", "MAD"))
        self.outlierTestCB.setItemText(1, _translate("MainWindow", "none"))
        self.label_37.setText(_translate("MainWindow", "Outlier test"))
        self.FDSmartStackGO.setText(_translate("MainWindow", "GO"))
        self.MADCutoff.setToolTip(_translate("MainWindow", "<html><head/><body><p>The threshold value used in the median absolute deviation outlier test. The default value of 1.4826 follows from an assumption of Gaussian noise, lower cutoff values are stricter and will throw out more samples.  </p></body></html>"))
        self.qdGroupBox.setTitle(_translate("MainWindow", "&Quadrature Detect"))
        self.qdGO.setText(_translate("MainWindow", "GO"))
        self.label_38.setText(_translate("MainWindow", "Trim"))
        self.QDType.setItemText(0, _translate("MainWindow", "Real/Imag"))
        self.QDType.setItemText(1, _translate("MainWindow", "Amp/Phase"))
        self.QDType.setItemText(2, _translate("MainWindow", "Phased"))
        self.plotQD.setText(_translate("MainWindow", "PLOT"))
        self.gateBox.setTitle(_translate("MainWindow", "Gate integrate"))
        self.gateIntegrateGO.setText(_translate("MainWindow", "GO"))
        self.label_53.setText(_translate("MainWindow", "Gates per decade "))
        self.QDType_2.setItemText(0, _translate("MainWindow", "Real/Imag"))
        self.QDType_2.setItemText(1, _translate("MainWindow", "Amp/Phase"))
        self.QDType_2.setItemText(2, _translate("MainWindow", "Phased"))
        self.plotGI.setText(_translate("MainWindow", "PLOT"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.QCTab), _translate("MainWindow", "QC"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Surface Loops"))
        self.loopTableWidget.setToolTip(_translate("MainWindow", "<html><head/><body><p>This table is used to enter coil geometries the format is as follows: each row specifies a single point on a coil. The first column is the coil index (using the GMR channel is useful), the next three colums specify the point in Northing, Easting, and Elevation. These can either be local coordinates or global ones. The final column specifies the loop radius if it is a circle or figure 8, for non circular or figure 8 loops leave this column blank. For figure-8 loops the coils do not need to be touching (see Irons and Kass, 2017). If a given index has 1 row it will be a circular loop, two rows will be a figure 8, and more than that will be a polygonal representation of the points, linearlly interpolated between them. </p></body></html>"))
        self.groupBox.setTitle(_translate("MainWindow", "Survey site information"))
        self.label_68.setText(_translate("MainWindow", "B Intensity [nT]"))
        self.label_66.setText(_translate("MainWindow", "B Declination [°] "))
        self.label_54.setText(_translate("MainWindow", "Temperature [°C]"))
        self.label_57.setText(_translate("MainWindow", "Survey date"))
        self.label_67.setText(_translate("MainWindow", "B Inclination [°]"))
        self.label_64.setText(_translate("MainWindow", "Survey time"))
        self.label_62.setText(_translate("MainWindow", "Location"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Comments and field notes"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.METATab), _translate("MainWindow", "META"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Integration Parameters"))
        self.label_70.setText(_translate("MainWindow", "min. level"))
        self.label_71.setText(_translate("MainWindow", "max. level"))
        self.label_72.setText(_translate("MainWindow", "branch tol"))
        self.label_2.setText(_translate("MainWindow", "Origin"))
        self.label_73.setText(_translate("MainWindow", "Size"))
        self.layerTableWidget.setToolTip(_translate("MainWindow", "<html><head/><body><p>This table is used to enter coil geometries the format is as follows: each row specifies a single point on a coil. The first column is the coil index (using the GMR channel is useful), the next three colums specify the point in Northing, Easting, and Elevation. These can either be local coordinates or global ones. The final column specifies the loop radius if it is a circle or figure 8, for non circular or figure 8 loops leave this column blank. For figure-8 loops the coils do not need to be touching (see Irons and Kass, 2017). If a given index has 1 row it will be a circular loop, two rows will be a figure 8, and more than that will be a polygonal representation of the points, linearlly interpolated between them. </p></body></html>"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.KernTab), _translate("MainWindow", "Kern"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.page), _translate("MainWindow", "Page 1"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.page_2), _translate("MainWindow", "Page 2"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.ModelTab), _translate("MainWindow", "Model"))
        self.invertButton.setText(_translate("MainWindow", "Invert"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.InvertTab), _translate("MainWindow", "INV"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.AppraiseTab), _translate("MainWindow", "Appraisal"))
        self.logTextBrowser.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Noto Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">All processing steps are recorded here for your records</span></p></body></html>"))
        self.label_74.setText(_translate("MainWindow", "Processing log"))
        self.ProcTabs.setTabText(self.ProcTabs.indexOf(self.LogTab), _translate("MainWindow", "Log"))
        self.headerFileBox.setTitle(_translate("MainWindow", "Expand header file information"))
        self.headerFileTextBrowser.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Noto Sans\'; font-size:8pt; font-weight:400; font-style:italic;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'DejaVu Serif\'; font-size:9pt;\">Load supported RAW Dataset header from file menu</span></p></body></html>"))
        self.label_6.setText(_translate("MainWindow", "ν Tx  [Hz]"))
        self.label_4.setText(_translate("MainWindow", "Pulse Type"))
        self.pulseTypeTextBrowser.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Noto Sans\'; font-size:10pt; font-weight:400; font-style:italic;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'DejaVu Serif\';\"><br /></p></body></html>"))
        self.label_9.setToolTip(_translate("MainWindow", "<html><head/><body><p>Number of pulse moments (q)</p></body></html>"))
        self.label_9.setText(_translate("MainWindow", "Num q"))
        self.label_13.setText(_translate("MainWindow", "τ Delay [ms]"))
        self.label_7.setText(_translate("MainWindow", "τ Pulse 1 [ms]"))
        self.label_17.setText(_translate("MainWindow", "FID 1 length [s]"))
        self.label_16.setText(_translate("MainWindow", "τ Pulse 2 [ms]"))
        self.label_39.setText(_translate("MainWindow", "FID 2 length [s]"))
        self.label_15.setText(_translate("MainWindow", "Instrument sampling  ν [Hz]"))
        self.label_40.setText(_translate("MainWindow", " re-sampling ν [Hz]"))
        self.label_14.setText(_translate("MainWindow", "Tx tuning [μF]"))
        self.label_47.setText(_translate("MainWindow", "total dead time"))
        self.menuOpen_GMR_RAW_Header.setTitle(_translate("MainWindow", "File"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.menuProcessing.setTitle(_translate("MainWindow", "Workflows"))
        self.actionOpen_GMR.setText(_translate("MainWindow", "&Open GMR Header"))
        self.actionOpen_Preprocessed_Dataset.setText(_translate("MainWindow", "Open Akvo Preprocessed dataset"))
        self.actionOpen_VC_Preprocessed_dataset.setText(_translate("MainWindow", "Open VC Preprocessed dataset"))
        self.actionSave_Preprocessed_Dataset.setText(_translate("MainWindow", "Save processing "))
        self.actionExport_Preprocessed_Dataset.setText(_translate("MainWindow", "Export to Lemma"))
        self.actionClose.setText(_translate("MainWindow", "Close"))
        self.actionAboutAkvo.setText(_translate("MainWindow", "About"))
        self.actionPreprocessing.setText(_translate("MainWindow", "Preprocessing"))
        self.actionModelling.setText(_translate("MainWindow", "Modelling"))
        self.actionInversion.setText(_translate("MainWindow", "Inversion"))


from akvo.gui.mydynamicmplcanvas import MyDynamicMplCanvas
from akvo.gui.mydynamicmplcanvasnavigator import MyDynamicMplCanvasNavigator
